@@ -4,8 +4,7 @@
 ice::Library* LIBRARY = NULL;
 char ERROR_MESSAGE[512];
 
-
-bool dll_initialize(void)
+bool __initialize(char* name)
 {
     if (dll_is_initialized()) {
         return true;
@@ -13,11 +12,18 @@ bool dll_initialize(void)
     try
     {
         memset(ERROR_MESSAGE, '\0', sizeof(ERROR_MESSAGE)/sizeof(ERROR_MESSAGE[0]));
+        if (!name)
+        {
 #if (defined(_WIN32) || defined(__WIN32__))
-        LIBRARY = new ice::Library("icsneo40.dll");
+            LIBRARY = new ice::Library("icsneo40.dll");
 #else
-        LIBRARY = new ice::Library("libicsneoapi.so");
+            LIBRARY = new ice::Library("libicsneoapi.so");
 #endif
+        }
+        else 
+        {
+            LIBRARY = new ice::Library(name);
+        }
     }
     catch (ice::Exception& ex)
     {
@@ -27,6 +33,11 @@ bool dll_initialize(void)
     return true;
 }
 
+bool dll_initialize(char* name)
+{
+    return __initialize(name);
+}
+
 bool dll_is_initialized(void)
 {
     return LIBRARY != NULL;
@@ -40,6 +51,12 @@ void dll_uninitialize(void)
     delete LIBRARY;
 }
 
+bool dll_reinitialize(char* name)
+{
+    dll_uninitialize();
+    return dll_initialize(name);
+}
+
 char* dll_get_error(char* error_msg)
 {
     strcpy(error_msg, ERROR_MESSAGE);
